var async = require('async');
var fs = require('fs');
var spawn = require('child_process').spawnSync;
var readline = require('readline');

var packages = require('./packages.json');
var yesToAll = false;

function isInstalled (packageName) {
  var cmd = spawn('pacman', ['-Qq', packageName]);
  return !cmd.status;
}

function getConfirm(callback) {
  if (yesToAll) return callback(true);

  var rl = readline.createInterface({
    input: process.stdin,
    output: process.stdout
  });

  rl.question("Do you want to delete these files and folders? [y/N/?a?/q]: ", function (answer) {
    answer = answer.toLowerCase();
    rl.close();
    if (answer === 'q') process.exit();
    else if (answer === 'a') {
      yesToAll = true;
      return callback(true);
    }
    else if (answer === 'y') return callback(true);
    else if (answer === 'n') return callback(false);
    else getConfirm();
  });
}

function isHomeDir (dir) {
  return dir.substring(0, 2) === '~/';
}

function removeFile (dir, callback) {
  if (isHomeDir(dir)) {
    spawn('rm', ['-rf', dir]);
  } else {
    spawn('sudo', ['rm', '-rf', dir]);
  }
  return callback();    
}

function parsePackage (package, callback) {
  if (!isInstalled(package.name)) {

    console.log(`Directories to remove for '${package.name}':`);
    console.log('\t' + package.dirs.join('\n\t'));

    getConfirm(function (answer) {
      if (answer) {
        console.log('Deleting...');

        async.eachSeries(package.dirs, removeFile, function (err) {
          if (err) { throw err; }
          console.log('Deleted!\n');

          return callback();
        });
      } else {
        console.log('Skipping...\n');
        return callback();
      }
    })
  } else {
    return callback();
  }
}


function main () {
  process.stdout.write('\033c');

  async.eachSeries(packages, parsePackage, function (err) {
    if (err) { throw err; }
    console.log('Mmmm.. Sooo cleeannn!');
  });
}

main();
